============================
Ensemble Parallel MDAnalysis
============================

|mdanalysis|

.. |mdanalysis| image:: https://img.shields.io/badge/powered%20by-MDAnalysis-orange.svg?logoWidth=16&logo=data:image/x-icon;base64, 
    :alt: Powered by MDAnalysis
    :target: https://www.mdanalysis.org
    
.. image:: https://img.shields.io/pypi/v/ENPMDA.svg
        :target: https://pypi.python.org/pypi/ENPMDA

.. image:: https://img.shields.io/travis/yuxuanzhuang/ENPMDA.svg
        :target: https://travis-ci.com/yuxuanzhuang/ENPMDA

.. image:: https://readthedocs.org/projects/ENPMDA/badge/?version=latest
        :target: https://ENPMDA.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status

.. warning::
    This is still under constrution.

ENPMDA
------

Parallel analysis for ensemble simulations
powered by MDAnalysis.
ENPMDA stores metadata in ``pandas.DataFrame``
and distributes computation jobs in ``dask.DataFrame``
so that the parallel analysis can be performed
not only for one single trajectory
but also across simulations and analyses.

It can be used as an initial inspection of
the raw trajectories as well as a framework for 
extracting features from final production simulations
for further e.g. machine learning and markov
state modeling. It automatically fixes the PBC issue and
align and center the protein inside the simulation box.
It also works for multimeric proteins!

The framework is intended to be adaptable by being able to
simply wrapping MDAnalysis analysis functions without worrying
about the parallel machinery behind.


* Free software: GNU General Public License v3
* Documentation: https://ENPMDA.readthedocs.io.